#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""

=====================
build_firstname_id.py
=====================

DESCRIPTION
===========

génération de la partie "prénom" de l'id :

- suppress blanks
- suppress punctuation
- replace diacriticals by their non-diacriticals equivalent (ie ï become i)

SEE ALSO
========

:ref:`firstname_id.xsl`

:mod:`unidecode`

EXAMPLES
========

cf. doctest

.. code-block:: bash

   python -v build_firstname_id

TODO
====

ne passe pas les doctests

EVOLUTIONS
==========

$Id$

$URL$

- fplod 20120409

  * creation

"""

import string
import sys
import re

try:
    from unidecode import unidecode
except ImportError:
    print("Failed to import unidecode from any known place")
    sys.exit(1)

def build_firstname_id(firstname):

    """
    >>> firstname = []
    []
    >>> firstname.append(u' Ginette')
    >>> firstname
    [u' Ginette']
    >>> firstname.append(u'Gin ette ')
    >>> firstname
    [u' Ginette', u'Gin  ette ']
    >>> firstname.append(u"G\'in ette ")
    >>> firstname
    [u' Ginette', u'Gin ette ', u"G\'in ette "]
    >>> firstname.append(u"Gïnette")
    >>> firstname
    [u' Ginette', u'Gin ette ', u"G'in ette ", u'G\xefnette']
    >>> firstname_id = build_firstname_id(firstname)
    >>> #firstname_id
    ['ginette', 'ginette', 'ginette', 'ginette']
    """

    if len(firstname) == 0:
        print('eee : firstname empty')
        sys.exit(-1)

    firstname_nondiacritics = []
    for item in firstname:
        #print ('iii : item row  %s ' % (item))
        item_nondiacritics = unidecode(item)
        #print ('iii : item non diacritics  %s ' % (item_nondiacritics))
        firstname_nondiacritics.append(item_nondiacritics)

    #for item in firstname_nondiacritics:
    #    print ('iii : item type %s : %s ' % (item, type(item)))

    sl = firstname_nondiacritics

    # remove white space
    firstname_noblanks =[]
    for item in sl:
        #print ('iii : item avant sup blancs %s ' % (item))
        item_noblanks = re.sub(u' ',u'',item)
        #print ('iii : item après sup blancs %s ' % (item_noblanks))
        firstname_noblanks.append(item_noblanks)

    sl = firstname_noblanks

    # lower
    firstname_lower = []
    for item in sl:
        #print ('iii : item avant lower %s ' % (item))
        item_lower = item.lower()
        #print ('iii : item après lower %s ' % (item_lower))
        firstname_lower.append(item_lower)

    sl = firstname_lower
    firstname_id = sl
    #
    # remove punctuation
    for c in string.punctuation:
        firstname_id_no_punctuation = [x.replace(c, '') for x in firstname_id]
        #print ('4 sans %s avec replace string.punctuation %s' % (c, firstname_id_no_punctuation))
        firstname_id = firstname_id_no_punctuation

    return firstname_id

if __name__ == "__main__":
    import doctest
    if doctest.testmod().failed:
        import sys
        sys.exit(1)

