#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

"""

===========
superbib.py
===========

DESCRIPTION
===========

collection de petits outils

.. option:: --ifile <file>

   file to read

.. only:: man

   Figure is visible on PDF and HTML documents only.

   .. only:: html or latex

      .. graphviz::

         digraph superbib {

             rh [shape=diamond,
                 fontname=Courier,
                 label='{ifile}'

         }

SEE ALSO
========

http://pybtex.sourceforge.net/manual.html

:func:`aeresrh`

EXAMPLES
========

.. code-block:: bash

   superbib.py --ifile /Users/fplod/superbib_ws/trunk/data/petitpoly.bib

   superbib.py --ifile /Users/fplod/superbib_ws/branches/bibliolocean/data/biblioref.bib --encoding ISO8859_1

TIPS
====

.. code-block:: bash

   sudo easy_install py26-pybtex

TODO
====

everything

EVOLUTIONS
==========

$Id$

$URL$

- fplod 20120405

  * creation
    thanks to http://personals.ac.upc.edu/xleon/publications.py

"""

import sys
import os
from os.path import dirname, basename
import glob
from optparse import OptionParser

import datetime

from operator import itemgetter
from pybtex.database.input import bibtex
from pybtex.core import Entry, Person

def get_option_parser ():
    """parse CLI arguments

           :returns: parser
          :rtype: :class:`optparse.OptionParser`
    """

    parser = OptionParser('%prog [--verbose ] --ifile file --encoding encoding')
    parser.add_option ('-V', '--verbose',
        help='produce verbose output',
        action='store_true',
        default=False,
        dest='is_verbose')
    parser.add_option ('-i', '--ifile',
        help='file to be read',
        type='string',
        dest='ifile',
        default=None,
        action='store')
    parser.add_option ('-e', '--encoding',
        dest='encoding',
        help='input encoding',
        default=None,
        action='store')

    return parser

def readbibtex(ifile, encoding, is_verbose):

    """"
      read a bibtex file
      return ++
    """

    parser = bibtex.Parser(encoding=encoding)

    if is_verbose == True:
        print('iii : read %s' % ifile)
    bibtex_data = parser.parse_file(ifile)

    return bibtex_data

def writehtml(bibtex_data):
    """ à aménager pour superbib"""
    supported_types = ['article', 'inproceedings', 'inbook', 'techreport', 'misc', 'manual', 'book']
    types_text = {'article': 'Journals',
                  'inproceedings': 'Conference Proceedings',
                  'inbook': 'Book chapters',
                  'techreport': 'Technical reports',
                  'misc' : 'divers',
                  'manual': 'manuel',
                  'book' : 'livre'}
    #
    # Initialize the dict with keys = publication type
    bibdict = dict()
    for type in supported_types:
        bibdict[type] = []

    # Put entries in the dict
    for k, v in bibtex_data.entries.items():
        bibdict[v.type].append((k, v))
        print 'Putting '+k+' in '+v.type

    # Print result
    f = open('ginette', 'w')
    for type in supported_types:
        print >> f, '<h2 class=biblio>'+types_text[type]+'</h2>'
        print >> f, '<ul>'
        for k, v in bibdict[type]:
            #++res = self.format_entry(type, k, v)
            res = type, k, v
            print >> f, '<li>',
            print >> f, res,
            print >> f, '</li>'
        print >> f, '</ul>'

def superbib():
    """main
        """
    try:
        parser = get_option_parser ()
        (fromcli, args) = parser.parse_args()
    except IOError, msg:
        parser.error(str(msg))

    is_verbose = fromcli.is_verbose
    ifile = fromcli.ifile
    encoding = fromcli.encoding
    if fromcli.is_verbose == True:
        print ('ifile : %s' % (ifile))

    bibtex_data = readbibtex(ifile, encoding, is_verbose)

    print (' toutes les bibtex keys : %s ' % bibtex_data.entries.keys())

    #okprint (' le titre de INTEL2002 %s ' % bibtex_data.entries['INTEL2002'].fields['title'])
    #okprint (' toutes les keys de fields : %s ' % bibtex_data.entries['INTEL2002'].fields.keys())
    #++print bibtex_data.entries
    #++print (' les auteurs de Met2004 %s ' % bibtex_data.entries['Met2004'].persons.['author'])

    #++print (' surname %s' % (surname))

    #pas faux mais pas malin status = writehtml(bibtex_data)

    # take everything with one name ++ pas seulement le 1er auteur
    firstname = u'Michael'
    surname = u'Metcalf'
    someone_all = {}
    for key in bibtex_data.entries.keys():
        try:
            print(' ref %s : ' % key)
            authors = bibtex_data.entries[key].persons['author']
            for author in authors:
                print('first name author :  %s ' % author.first())
                print('last name author :  %s ' % author.last())
                try:
                    if ((author.first()[0] == firstname) and (author.last()[0] == surname)):
                        someone_all[key] = bibtex_data.entries[key]
                except IndexError: # no first / last name
                    pass
        except KeyError: # no author (e.g. a collection)
            pass

    # categorise
    someone_nonref = {}
    someone_nonref_sort = []
    someone_proc = {}
    someone_proc_sort = []
    someone_ref = {}
    someone_ref_sort = []
    for key in someone_all.keys():
        publ = someone_all[key]
        year = -int(publ.fields['year'].strip('-')) # strip for 2009--; - to get the ones with largest years first
        for i in range(len(publ.persons['author'])):
            if ((publ.persons['author'][i].first()[0] == firstname) and (publ.persons['author'][i].last()[0] == surname)):
                mypos = i
                break
        if ((publ.type == "techreport") or (publ.type == "mastersthesis") or (publ.type == "phdthesis") or (publ.type == "misc") or ("nonrefereed" in publ.fields.keys())):
            someone_nonref[key] = someone_all[key]
            someone_nonref_sort.append((key, year, mypos))
        elif (publ.type == "inproceedings"):
            someone_proc[key] = someone_all[key]
            someone_proc_sort.append((key, year, mypos))
        #++ pas de journal dans demo poly elif (publ.fields['journal'] != "in preparation"):
        elif (publ.fields['title'] != "in preparation"):
            try:
                vol = publ.fields['volume']
            except KeyError:
                vol = None
            if (vol != "submitted"):
                someone_ref[key] = someone_all[key]
                someone_ref_sort.append((key, year, mypos))

    # sort
    # the newest publications first
    #     the ones where i'm first author first
    someone_nonref_sorted = [i[0] for i in sorted(someone_nonref_sort, key=itemgetter(1,2))]
    someone_proc_sorted = [i[0] for i in sorted(someone_proc_sort, key=itemgetter(1,2))]
    someone_ref_sorted = [i[0] for i in sorted(someone_ref_sort, key=itemgetter(1,2))]
    for i in [(someone_nonref_sorted, 'nonref.txt'), (someone_proc_sorted, 'proc.txt'), (someone_ref_sorted, 'ref.txt')]:
        f = open(i[1], 'w')
        for line in i[0]:
            f.write(str(line)+"\n")
        f.close()

# Run main, if called from the command line
if __name__ == '__main__':
    superbib()
