<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet
version="1.0"
xmlns:d="http://docbook.org/ns/docbook"
xmlns:xl="http://www.w3.org/1999/xlink"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--rst

.. _superbib01_xml.xsl:

==================
superbib01_xml.xsl
==================

produce a DocBook 5 with bibliograhy references sorted by years

SEE ALSO
========

:ref:`biblioentry_rest.xsl`

TODO
====

link sur top chaque section
:ref:`top` ../../images/globalicondl11x10_up.gif

tableau d'annes

EVOLUTIONS
==========

$Id$

- fplod 2001228

  * recreation

-->

<xsl:output
 method="text"
 indent="yes"/>

<xsl:include href="biblioentry_rest.xsl"/>

<xsl:variable name="list_years" select="///d:pubdate[not( self::node() = following::d:pubdate )]"/>

<xsl:variable name="project">
 <xsl:value-of select="document('main.xml')//d:keyword[@xml:id='project']"/>
</xsl:variable>

<xsl:template name="years">
<!--
creation of an informatable of nb years
each entry of the table is a link #year_xxxx
-->
<xsl:element name="informaltable">
 <xsl:attribute name="xml:id">years</xsl:attribute>
 <xsl:attribute name="summary">years of publications</xsl:attribute>
 <xsl:element name="tgroup">
  <xsl:variable name="nb_cols" select="count($list_years)"/>
  <xsl:attribute name="cols"><xsl:value-of select="$nb_cols"/></xsl:attribute>
  <xsl:attribute name="align">center</xsl:attribute>
  <xsl:attribute name="colsep">1</xsl:attribute>
  <xsl:attribute name="rowsep">1</xsl:attribute>
  <xsl:for-each select="///d:pubdate[not( self::node() = following::d:pubdate )]">
   <xsl:sort order="descending" data-type="number" select="."/>
   <xsl:element name="colspec">
    <xsl:attribute name="colname">year_<xsl:value-of select="."/></xsl:attribute>
   </xsl:element>
  </xsl:for-each>
  <xsl:element name="tbody">
   <xsl:element name="row">
    <xsl:for-each select="///d:pubdate[not( self::node() = following::d:pubdate )]">
     <xsl:sort order="descending" data-type="number" select="."/>
     <xsl:element name="entry">
      <xsl:attribute name="colname"><xsl:text>year_</xsl:text><xsl:value-of select="."/></xsl:attribute>
      <xsl:element name="link">
       <xsl:attribute name="xl:href"><xsl:text>#year_</xsl:text><xsl:value-of select="."/></xsl:attribute>
       <xsl:value-of select="."/>
      </xsl:element>
     </xsl:element>
    </xsl:for-each>
   </xsl:element>
   <xsl:element name="row">
    <xsl:for-each select="///d:pubdate[not( self::node() = following::d:pubdate )]">
     <xsl:sort order="descending" data-type="number" select="."/>
     <xsl:element name="entry">
      <xsl:attribute name="colname"><xsl:text>year_</xsl:text><xsl:value-of select="."/></xsl:attribute>
      <xsl:element name="emphasis">
       <xsl:attribute name="role">bold</xsl:attribute>
<xsl:variable name="nb_current">
 <xsl:variable name="current_year"><xsl:value-of select="."/></xsl:variable>
 <xsl:value-of select="count(/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$current_year]])"/>
</xsl:variable>
       <xsl:value-of select="$nb_current"/>
      </xsl:element>
     </xsl:element>
    </xsl:for-each>
   </xsl:element>
   <xsl:variable name="year_min">
    <xsl:value-of select="///d:pubdate[not(. &gt; ///d:pubdate)]"/>
   </xsl:variable>
   <xsl:variable name="year_max">
    <xsl:value-of select="///d:pubdate[not(. &lt; ///d:pubdate)]"/>
   </xsl:variable>
   <xsl:element name="row">
    <xsl:element name="entry">
     <xsl:attribute name="namest"><xsl:value-of select="concat('year_',$year_max)"/></xsl:attribute>
      <xsl:attribute name="nameend"><xsl:value-of select="concat('year_',$year_min)"/></xsl:attribute>
     <xsl:element name="emphasis">
      <xsl:attribute name="role">bold</xsl:attribute>
       <xsl:value-of select="count(/descendant::d:biblioentry)"/>
     </xsl:element>
    </xsl:element>
   </xsl:element>
  </xsl:element>
 </xsl:element>
</xsl:element>
</xsl:template>

<xsl:template match="d:bibliography">

<xsl:value-of select="$project"/> - Publications - Papers by years
==================================================================

.. _top:

This page intents to provide an exhaustive list of the papers that have used
<xsl:value-of select="$project"/> and/or results from them.
Obvioulsy many papers are missing.
If you find omissions or mistakes please ask some modification via
:ref:`main`

You can also see **<xsl:value-of select="$project"/> - Publications - Papers** sorted by
authors in :ref:`superbib02`
or in :ref:`superbib01many` several
one by author)

<xsl:call-template name="para_lastupdate_bib">
 <xsl:with-param name="language" select="@xml:lang"/>
 <xsl:with-param name="date" select="d:info/d:date"/>
 <xsl:with-param name="mode" select="'rest'"/>
</xsl:call-template>

<xsl:call-template name="years"/>

.. _fig_pubbyyears:

.. figure:: ../../images/years.png
   :alt:[years.png]

   Nb of publications by years

.. _intro:

Introduction
============

This document provide bibliography sorted by year.

   <!-- loop on years -->
   <xsl:for-each select="$list_years">
    <xsl:sort order="descending" data-type="number" select="."/>
    <xsl:call-template name="one_year">
     <xsl:with-param name="year" select="."/>
    </xsl:call-template>
   </xsl:for-each>
</xsl:template>

<xsl:template match="d:info/d:date"/>
<xsl:template match="d:bibliography/d:title"/>

<xsl:template name="one_year">
<xsl:param name="year"/>
<!--
 <xsl:message>call template avec <xsl:value-of select="$year"/></xsl:message>
 <xsl:message>noeud courant <xsl:value-of select="name(.)"/></xsl:message>
 <xsl:message>
year_<xsl:value-of select="$year"/> : <xsl:value-of select="count(/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$year]]) + count(/descendant::d:biblioentry[child::d:date=$year])"/>
</xsl:message>
-->

.. _<xsl:value-of select="concat('year_',$year)"/>:

<xsl:value-of select="$year"/>
=========

   <xsl:for-each select="/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$year]]|/descendant::d:biblioentry[child::d:date=$year]">
    <xsl:sort order="ascending" data-type="text" select="translate(./authorgroup/author/personname,'abcdefghijklmnopqrstuvwxyz ','ABCDEFGHIJKLMNOPQRSTUVWXYZ_EECAUEONO')"/>
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>- </xsl:text>
    <xsl:call-template name="one_biblioentry_rest">
     <xsl:with-param name="visu_modif" select="'visu'"/>
     <xsl:with-param name="type" select="'raw'"/>
     <xsl:with-param name="my_biblioentry" select="."/>
    </xsl:call-template>
    <xsl:text>&#xA;</xsl:text>
   </xsl:for-each>
</xsl:template>

</xsl:stylesheet>
