<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet
version="1.0"
xmlns:d="http://docbook.org/ns/docbook"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--rst

.. _years_matplotlib.xsl:

====================
years_matplotlib.xsl
====================

DESCRIPTION
===========

production d'un fichier de commande matplotlb avec donnes incorpores pour
le graphe publications/anne

EXAMPLES
========

.. code-block:: sh

  xsltproc \-\-param makedate $((date)) \-\-param path "'.'" \-\-output ginette.py years_matplotlib.xsl biblio.xml
  python ginette.py
  open ++.png

TODO
====

x time axe with yyyy labels

add in makefile

see http://matplotlib.sourceforge.net/examples/pylab_examples/demo_ribbon_box.html

doctest

EVOLUTIONS
==========

$Id$

$URL$

- fplod 20120228

  * add yticks and ylim
  * remove plot_shox to avoid interaction

- fplod 20110627T144044Z aedon.locean-ipsl.upmc.fr (Darwin)

  * creation draft

-->

<xsl:output
 method="text"
 encoding="ISO-8859-1"
 indent="yes"/>

<xsl:include href="biblioentry_xml.xsl"/>

<xsl:variable name="list_years" select="///d:pubdate[not( self::node() = following::d:pubdate )]"/>

<xsl:template match="d:bibliography">
""""

EXAMPLES
========

.. code-block:: bash

   python years_matplotlib.py

EVOLUTIONS
==========

<xsl:value-of select="$makedate"/>

"""

import matplotlib.pyplot as plot
import numpy as np
import datetime

fig = plot.figure()
ax = fig.gca()

# definition of axes
ax.set_xlabel('Year')
ax.set_ylabel('Nb of publications')
# titre sur le graphique
plot.title('nb of publications by year date : <xsl:value-of select="$makedate"/>')
#

dates=[]
values=[]
   <!-- loop on years -->
   <xsl:for-each select="$list_years">
    <xsl:sort order="ascending" data-type="number" select="."/>
    <xsl:call-template name="one_year">
     <xsl:with-param name="year" select="."/>
    </xsl:call-template>
   </xsl:for-each>

ax.set_ylim(min(values)-1, max(values)+1)
ax.set_xlim(dates[0]-0.5, dates[-1]+0.5)
plot.yticks(np.arange(min(values)-1,max(values)+1,1))
plot.bar(dates, values,width=0.5)

# avoid overlap on labels
fig.autofmt_xdate()
#
fig.savefig('<xsl:value-of select="$path"/>/years.png')

</xsl:template>

<xsl:template name="one_year">
<xsl:param name="year"/>
dates.append(<xsl:value-of select="$year"/>)
<xsl:text> </xsl:text>
values.append(<xsl:value-of select="count(/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$year]]) "/>)
<xsl:text>&#xA;</xsl:text>
</xsl:template>

</xsl:stylesheet>
